/*+----------------------------------------------------------------+
  | Copyright (c) 2009 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
  | Name:     etlldfct.sas
  | Purpose:  Allow to load base facts into SDM from ETL studio
  |
  | Parameters:
  |
  |     actionType 1=replace all
  |     actionType 2=replace matching
  |
  !     table is the table holding Dimension and Member codes.
  |     This table can be created in the transformation pre-code area.
  |     The table must have SAS_DIM_CODE and SAS_MBR_CODE columns.
  |     The SAS code below creates an example table:
  |        data WORK.BASE_FACT_dimMbrSelection;
  |           length SAS_DIM_CODE SAS_MBR_CODE $32 ;
  |           SAS_DIM_CODE = "TIME_DIM" ;
  |           SAS_MBR_CODE = "JAN2003";
  |           output ;
  |           SAS_MBR_CODE = "FEB2003" ;
  |           output ;
  |           SAS_DIM_CODE = "ANALYSIS_DIM";
  |           SAS_MBR_CODE = "ACTUAL" ;
  |            output ;
  |           SAS_MBR_CODE = "BUDGET" ;
  |           output ;
  |        run ;
  +----------------------------------------------------------------+*/


%macro etlldfct(cycle, table, source, actionType, delPreserveForm,
                                      delIgnoreCurrency, environment);

  proc sort data=&table nodups;
    by SAS_DIM_CODE SAS_MBR_CODE;
  run;  

  data _null_;
    set &table nobs=_nobs;
    call symput('_nobs', _nobs);
    stop;
  run;

  data _null_ /picklist='finance/finance.txt' saveclassl="finbatch" getclassl="finbatch";

    array dimCodes[&_nobs] $32 ;
    array mbrCodes[&_nobs] $32 ;
    retain cnt 1 ;
    retain dimCodes mbrCodes;

    set &table end=nRunJavaOBJ;

    dimCodes[cnt] = strip(sas_dim_code);
    mbrCodes[cnt] = strip(sas_mbr_code);
    cnt + 1;

    if nRunJavaOBJ then do;

      dcl javaobj j("com/sas/solutions/finance/api/BaseFactLoad");
      j.ExceptionDescribe(1);

      if symget("environment") ne "" then
        j.callVoidMethod("setEnvironment", "&environment");

      call METADATA_PASSID("j", "");

      length src $1;
      length cycle $ 100;
      length source $ 32;
      length msg $ 512;
      length url $ 1000;
      length actionType $ 1;
      length count $ 7;
      table=symget("table");
      cycle=symget("cycle");
      source=symget("source");
      actionType=symget("actionType");
      delPreserveForm=symget("delPreserveForm");
      delIgnoreCurrency=symget("delIgnoreCurrency");

      put cycle= table= source= actionType=;

      if (strip(actionType) eq '1') then do ;
          delIgnoreCurrency = '0';
      end;
      else do;
          delPreserveForm = '0';
      end ;

      j.callStringMethod("loadBaseFacts", strip(cycle), dimCodes, mbrCodes, strip(source),
                                          strip(actionType), strip(delPreserveForm),
                                          strip(delIgnoreCurrency), src);

      j.callStringMethod("getMessage", msg);
      put msg= ;

      /*  Status handling  */
      if strip(src) = "0" then do;
         * load successful ;
         j.callStringMethod("getTransactionsCount", count);
         put 'Note: successfully import ' count ' facts.';
      end;
      else if strip(src) = "3" then do;
      end;
      else do;
         j.callStringMethod("getReportURL", url);
         if url ne '' then do ;
           put 'Note: for further information please see report at URL:' url;
         end ;
         *j.callVoidMethod("logout");
         j.delete();
         abort ;
      end;
      *j.callVoidMethod("logout");
      j.delete();

    end;
  run;

%mend;
